@@ -779,4 +779,13 @@ folio = Classification(lambda x: " ".join(x.premises),"conclusion",
 
 tomi_nli = Classification("premise","hypothesis","label",
     dataset_name="metaeval/tomi-nli"
-)
\ No newline at end of file
+)
+
+avicenna = Classification("Premise 1","Premise 2","Syllogistic relation",
+    dataset_name="metaeval/avicenna")
+
+shp = MultipleChoice("history",
+    choices=['human_ref_A','human_ref_B'],
+    labels="labels",
+    dataset_name="stanfordnlp/SHP")
+
